@@ -3,6 +3,7 @@ import os
 import io
 import base64
 from io import BytesIO
+import hashlib
 
 class PyMinio:
     def __init__(self, host, port, access_key, secret_key, secure=False):
@@ -101,7 +102,7 @@ class PyMinio:
 
             hash_md5 = hashlib.md5()
             hash_md5.update(image_data)
-            image_name = hash_md5.hexdigest() + "." + filetype
+            image_name = hash_md5.hexdigest()
             object_name = "{}/{}.{}".format(image_name[:2], image_name[2:], filetype)
 
         result = self.client.put_object(bucket, object_name, BytesIO(image_data), len(image_data))
